%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% StemGL_Fit Single stem Greenlab Fitting tool and
% StemGL_Sim Single stem GreenLab Simulation tool
%
%   MatLab_Octave code. 
%
% This code is part of GREENLAB project StemGL implementation
%
% Main Author: Philippe de Reffye CIRAD-AMAP
% Secondary author: Marc JAEGER CIRAD-AMAP
%
% Created: 2018
% Version 18_10_05
%
% Copyright (C) 2018 CIRAD-AMAP 
%
% This program is free software: you can redistribute it and/or modify it
% under the terms of the Create Commons Licence  type 5, BY-NC-SA
% BY (Attribution): Licensees may copy, distribute, display and perform the work and make derivative
% works and remixes based on it only if they give the author or licensor the credits (attribution)
% in the manner specified by these.
% SA (Share-alike): Licensees may distribute derivative works only under a license identical
% ("not more restrictive") to the license that governs the original work.
% NC (Non-commercial): 	Licensees may copy, distribute, display, and perform the work and
% make derivative works and remixes based on it only for non-commercial purposes.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function Draw_Plant(chrono,No,Leaf_Display,Internode_Display,Fruit_Display,T,Tm,Axdc,...
ta,na,nf,nm,nt,TQTs,qdics,qlis,qdas,qlas,qdfs,qlfs,qdms,qlms)
%%%

    % MJ correction 2018 05 11 added 3 lines
    dlmax = max(qlas);
    dlm = max(dlmax);
    decal_x = 2.0*max(dlm)+ 0.5;

    % define viewpoint boundaries 
    ym = 1.02 * sum (qlis(T,1:T,1));  % max on y axis
    if decal_x*(No+0.05) > ym               % max on x axis greater ?
      ym = decal_x*(No+0.05);
    end 
    xmi = -decal_x;
    xma = xmi+ym+8;
    ymi = -4;
    yma = ymi+ym+8;

    if chrono > 0
        figure (12);
        set (figure (12), 'Name', 'Plant chronological development and growth ');
        %Dessin:

        %%%%m%%%%%%%%%%%%%%%%%%%%%%%%%
        % display chronological axis

        hold on;
        clf; % clear figure necessary for animation
        axis([xmi xma ymi yma]); 

        pos_x = 0;

        for s=1:No
            qlpred = 1.0;
            qdpred = 0.1;
            pos_y = 0;
            for i=1:T
                % defined length and diameter from previous one if break 
                if Axdc(i,s) > 0
                    qlpred = qlis(Tm,i,s); % store length and diameter
                    qdpred = qdics(Tm,i,s);
                else
                    qlis(Tm,i,s)  = qlpred; % retrieve previous length and diameter
                    qdics(Tm,i,s) = qdpred;
                end
                Draw_Organ(Leaf_Display,Internode_Display,Fruit_Display,...
                    T,i,ta,na(i,s),nf(i,s),nm(i,s),nt,TQTs(T,s),pos_x,pos_y,...
                    Axdc(i,s),qdics(T,i,s),qlis(T,i,s),qdas(T,i,s),qlas(T,i,s),qdfs(T,i,s),qlfs(T,i,s),qdms(T,i,s),qlms(T,i,s));
                pos_y = pos_y + qlis(Tm,i,s);
            end
            pos_x = pos_x + decal_x;
        end
        hold off;
    end

    fig13 = figure (13);
    set (fig13, 'Name', 'Plant topological development and growth  ');
    %Dessin:

    uicontrol(fig13,'Style', 'pushbutton', 'String', 'Close',...
            'Position', [20 20 50 20],...
            'Callback', 'close(13)');        

    % display plant growth architecture

    % first view is at final age even when animation
    t = T; % animation : t = 1;  else  t = T
    k = t; 
    while k <= T  
        hold on;
        clf; % clear figure necessary for animation
        axis([xmi xma ymi yma]); 
    %    axis equal;
        pos_x = 0;
        for s=1:No
            pos_y = 0;        
            for i=1:t
                if Axdc(i,s) > 0
                    Draw_Organ(Leaf_Display,Internode_Display,Fruit_Display,...
                       t,i,ta,na(i,s),nf(i,s),nm(i,s),nt,TQTs(t,s),pos_x,pos_y,...
                       Axdc(i,s),qdics(t,i,s),qlis(t,i,s),qdas(t,i,s),qlas(t,i,s),qdfs(t,i,s),qlfs(t,i,s),qdms(t,i,s),qlms(t,i,s));
                    pos_y = pos_y + qlis(t,i,s);
                end
            end
            pos_x = pos_x + decal_x;
        end
        % This part is for growth animation

        if k < T
            %axis equal;
            % click mouse or press button for next step
            try
                action = waitforbuttonpress;
                if action > 0
                    k = T-1;
                end
            catch err
                close(fig13);
                return ;
            end
        end
        k = k+1;
        t = k;
        hold off;
    end

end