%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% StemGL_Fit Single stem Greenlab Fitting tool and
% StemGL_Sim Single stem GreenLab Simulation tool
%
%   MatLab_Octave code. 
%
% This code is part of GREENLAB project StemGL implementation
%
% Main Author: Philippe de Reffye CIRAD-AMAP
% Secondary author: Marc JAEGER CIRAD-AMAP
%
% Created: 2018
% Version 18_10_05
%
% Copyright (C) 2018 CIRAD-AMAP 
%
% This program is free software: you can redistribute it and/or modify it
% under the terms of the Create Commons Licence  type 5, BY-NC-SA
% BY (Attribution): Licensees may copy, distribute, display and perform the work and make derivative
% works and remixes based on it only if they give the author or licensor the credits (attribution)
% in the manner specified by these.
% SA (Share-alike): Licensees may distribute derivative works only under a license identical
% ("not more restrictive") to the license that governs the original work.
% NC (Non-commercial): 	Licensees may copy, distribute, display, and perform the work and
% make derivative works and remixes based on it only for non-commercial purposes.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [qas,qps,qics,qfs,qms]...
    =Growth_Ax_Sorts(T,Tm,N,Axdc,qav,qpv,qicv,qfv,qmv,np,nf,nm,pa,pp,pe,pf,pm)
qax=zeros(T,T);nax=qax;qas=qax;nas=qax;
if pp >0
    qpx=zeros(T,T);npx=qax;qps=qax;nps=qax;
else
    qpx=0;npx=qax;qps=0;nps=0;
end
qicx=zeros(T,T);nix=qicx;qics=qax;nis=qax;
if pf >0
    qfx=zeros(T,T);nfx=qax;qfs=qax;nfs=qax;
else
    qfx=0;nfx=0;qfs=qax;nfs=0;
end
if pm >0
    qmx=zeros(T,T);nmx=qax;qms=qax;nms=qax;
else
    qmx=0;nmx=0;qms=0;nms=0;
end

%%%%%%%%%%%%%%%%%%%%%%
% List mode
%%%%%%%%%%%%%%%%%%%%%
nix=zeros(T,T);nixs=zeros(T,T,N);niss=nixs;% to use matrix operator and not divide by zero!
qaxs=zeros(T,T,N);qass=qaxs;
if pp >0
    qpxs=qaxs;qpss=qaxs;
end
qicxs=qaxs;qiss=qaxs;qicss=qaxs;
if pf >0
    qfxs=qaxs;qfss=qaxs;
    nfx=zeros(T,T);nfxs=zeros(T,T,N);nfss=nixs;
end
if pm >0
    qmxs=qaxs;qmss=qaxs;
    nmx=zeros(T,T);nmxs=zeros(T,T,N);nmss=nixs;
end
%%%%%%%%
% collection
%%%%%%%%%
for s=1:N
    %%%%%%%%%%%%%%%%%%%%%%%%
    % L I S T M O D E
    %%%%%%%%%%%%%%%%%%%%%%%%
    for i=1:T % for all age
        for j=1:i% exploration main structure
            %%% full axis with pause for shrubs or tree if lenght & diameter
            qaxs(j,i,s)=qaxs(j,i,s)+qav(i,j,s);
            if pp >0
                qpxs(j,i,s)=qpxs(j,i,s)+qpv(i,j,s);
            end
            qicxs(j,i,s)=qicxs(j,i,s)+qicv(i,j,s);
            nixs(j,i,s)=nixs(j,i,s)+Axdc(j,s);
            if pf >0
                qfxs(j,i,s)=qfxs(j,i,s)+qfv(i,j,s);
                nfxs(j,i,s)=nfxs(j,i,s)+Axdc(j,s)*sign(nf(j,s));% may be no fruit!
            end
            if pm >0
                qmxs(j,i,s)=qmxs(j,i,s)+qmv(i,j,s);
            end
            %%% axis without pauses
            % so recuperate the AXD of the item!
            Lo=sum(Axdc(j+1:i,s)); % we know the branch topo with so!
            sho=i-j-Lo;% shift inside axis for observation
            j1=j+sho;
            % blade
            qass(j1,i,s)=qass(j1,i,s)+qav(i,j,s);
            if pp >0
                qpss(j1,i,s)=qpss(j1,i,s)+qpv(i,j,s);
            end
            % internode
            qicss(j1,i,s)=qicss(j1,i,s)+qicv(i,j,s);
            niss(j1,i,s)=niss(j1,i,s)+Axdc(j,s);
            if pf >0
                qfss(j1,i,s)=qfss(j1,i,s)+qfv(i,j,s);
                nfss(j1,i,s)=nfss(j1,i,s)+Axdc(j,s)*sign(nf(j,s));
            end
            if pm >0
                qmss(j1,i,s)=qmss(j1,i,s)+qmv(i,j,s);
                nmss(j1,i,s)=nmss(j1,i,s)+Axdc(j,s)*sign(nm(j,s));
            end
        end %t nbs
    end %i
    % statistics for GL2
    qax(:,:)=qax(:,:)+qaxs(:,:,s);qas(:,:)=qas(:,:)+qass(:,:,s);
    if pp >0
        qpx(:,:)=qpx(:,:)+qpxs(:,:,s);qps(:,:)=qps(:,:)+qpss(:,:,s);
    end
    qicx(:,:)=qicx(:,:)+qicxs(:,:,s);qics(:,:)=qics(:,:)+qicss(:,:,s);
    nix(:,:)=nix(:,:)+nixs(:,:,s);nis(:,:)=nis(:,:)+niss(:,:,s);% number of phyt
    if pf >0
        qfx(:,:)=qfx(:,:)+qfxs(:,:,s);qfs(:,:)=qfs(:,:)+qfss(:,:,s);
        nfx(:,:)=nfx(:,:)+nfxs(:,:,s);nfs(:,:)=nfs(:,:)+nfss(:,:,s);% number of phyt
    end
    if pm >0
        qmx(:,:)=qmx(:,:)+qmxs(:,:,s);qms(:,:)=qms(:,:)+qmss(:,:,s);
        nmx(:,:)=nmx(:,:)+nmxs(:,:,s);nms(:,:)=nms(:,:)+nmss(:,:,s);% number of phyt
    end
end %s




%%%%%%%%%%
% end collection
%%%%%%%%%%
% statistics
Sgnnix=sign(nix);Sgnnis=sign(nis);onenixs=ones(T,T);
dnnix=abs(onenixs- Sgnnix);dnnis=abs(onenixs- Sgnnis); % so no more 0 for dicviding
nix=nix+dnnix;nis=nis+dnnis;
% diam
% average
qax=qax./(nix);qas=qas./(nis);
if pp >0
    qpx=qpx./(nix);qps=qps./(nis);
end
qicx=qicx./(nix);qics=qics./(nis);
if pf >0
    Sgnnfx=sign(nfx);Sgnnfs=sign(nfs);onenfxs=ones(T,T);
    dnnfx=abs(onenfxs- Sgnnfx);dnnfs=abs(onenfxs- Sgnnfs); % so no more 0 for dicviding
    nfx=nfx+dnnfx;nfs=nfs+dnnfs;
    qfx=qfx./(nfx);qfs=qfs./(nfs);
end
if pm >0
    qmx=qmx./(nix);qms=qms./(nis);
end
% conditioning data for glsqr
% all tips of axis on bottom for multifitting
qtemp=qics;
[qas]=crunchq_downqo(qas,qtemp,T);
if pp >0
    [qps]=crunchq_downqo(qps,qtemp,T);
end
[qics]=crunchq_downqo(qics,qtemp,T);
if pf >0
    [qfs]=crunchq_downqo(qfs,qtemp,T);
end
if pm >0
    [qms]=crunchq_downqo(qms,qtemp,T);
end
% conditionning phyt for out of range
for i=1:T
    for j=T-i+1:-1:1
        if j ~= T-i +1 % -1 for out of range ...
            qas(j,i)=-1;
            if np >0
                qps(j,i)=-1;
            end
            qics(j,i)=-1;
            if pf >0
                qfs(j,i)=-1;
            end
            if pm >0
                qms(j,i)=-1;
            end
        end
    end
end
% conditioning pause and position of absent fruit
for i=1:T
    for j=T:-1:T-i+1
        if Tm ==0 %% rosette ?
            if qas(j,i) ==0
                qas(j,i)=-0.0001;
            end
            if pp >0
                if qps(j,i) ==0
                    qps(j,i)=-0.0001;
                end
            end
        else
            if qas(j,i) ==0 && j < T
                qas(j,i)=-0.0001;
            end
            if pp >0
                if qps(j,i) ==0 && j < T
                    qps(j,i)=-0.0001;
                end
            end
        end
        if qics(j,i) ==0
            qics(j,i)=-0.0001;
        end
        if pf >0
            if qfs(j,i) ==0
                qfs(j,i)=-0.0001;
            end
        end
        if pm >0
            if qms(j,i) ==0
                qms(j,i)=-0.0001;
            end
        end
    end
end

