%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% StemGL_Fit Single stem Greenlab Fitting tool and
% StemGL_Sim Single stem GreenLab Simulation tool
%
%   MatLab_Octave code. 
%
% This code is part of GREENLAB project StemGL implementation
%
% Main Author: Philippe de Reffye CIRAD-AMAP
% Secondary author: Marc JAEGER CIRAD-AMAP
%
% Created: 2018
% Version 18_10_05
%
% Copyright (C) 2018 CIRAD-AMAP 
%
% This program is free software: you can redistribute it and/or modify it
% under the terms of the Create Commons Licence  type 5, BY-NC-SA
% BY (Attribution): Licensees may copy, distribute, display and perform the work and make derivative
% works and remixes based on it only if they give the author or licensor the credits (attribution)
% in the manner specified by these.
% SA (Share-alike): Licensees may distribute derivative works only under a license identical
% ("not more restrictive") to the license that governs the original work.
% NC (Non-commercial): 	Licensees may copy, distribute, display, and perform the work and
% make derivative works and remixes based on it only for non-commercial purposes.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [F_S] = Growth_Beta(n,tx,Bo1,Bo2)
% 
% function [F_S] = Growth_Beta(n,tx,Bo1,Bo2)
% 
% computes normalize beta law (Bo1,bo2) on a given period
%   I   n:          number of durations to consider (usually plant age)
%   I   tx(1:n):    Beta Law intervals 
%   I   Bo1:        Beta Law first parameter
%   I   Bo2:        Beta Law second parameter
%   O   F_S(n,n+1)  BetaLaw output F_S(i=1:n, 1:tx(i))
%
%   Last version 2018/10/23 Main author PdR/MJ
%   Copyright Cirad-AMAP
%
    nt = int32(max(tx)) + n + 1;
    F_O = zeros(nt,1);
    F_S = zeros(n,n+1);
    Bo1 = Bo1-1;
    Bo2 = Bo2-1;
    for i=1:n
        txi = tx(i);
        ftxi = 1.0;
        if (txi > 0)
            ftxi = 1.0 / txi;
        end
        % MJ 18/10/22

        S = 0.0;
        x = ftxi*0.5;
        for j = 1 : txi
            F_O(j) = x^Bo1  *  (1 - x)^Bo2   *  ftxi;
            x = x + ftxi;
            if S < F_O(j)
                S = F_O(j);
            end
        end
        %computing classes and cumulating function
        if S > 0.000001
             S = 1 / S;
           else
             S = 0.0;
        end     
        if (txi > n)
             txi = n;
        end
        for j = 1 : txi 
            F_S(i,j)= F_O(j) * S;
        end
    end
end
