%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% StemGL_Fit Single stem Greenlab Fitting tool and
% StemGL_Sim Single stem GreenLab Simulation tool
%
%   MatLab_Octave code. 
%
% This code is part of GREENLAB project StemGL implementation
%
% Main Author: Philippe de Reffye CIRAD-AMAP
% Secondary author: Marc JAEGER CIRAD-AMAP
%
% Created: 2018
% Version 18_10_05
%
% Copyright (C) 2018 CIRAD-AMAP 
%
% This program is free software: you can redistribute it and/or modify it
% under the terms of the Create Commons Licence  type 5, BY-NC-SA
% BY (Attribution): Licensees may copy, distribute, display and perform the work and make derivative
% works and remixes based on it only if they give the author or licensor the credits (attribution)
% in the manner specified by these.
% SA (Share-alike): Licensees may distribute derivative works only under a license identical
% ("not more restrictive") to the license that governs the original work.
% NC (Non-commercial): 	Licensees may copy, distribute, display, and perform the work and
% make derivative works and remixes based on it only for non-commercial purposes.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [qo,qomc,nqomc,Qmob_is,TQo_is]=...
    Organ_GrowthS(Q_D,qo,qomc,nqomc,Qmob_is,i,Axdc,...
    tfo,mno,co,no,nf,po,kpo,Bo,Dlo,TQo_is,dim,s)
% function  [qo,mxqo,qomc,nqomc,Qmob_is,TQo_is]= Organ_GrowthS(Q_D,qo,mxqo,qomc,nqomc,Qmob_is,i,s,Axdc,tfo,mno,co,no,nf,po,kpo,Bo,Dlo,TQo_is)
%
% Organ growth at cycle i
%   I:   Q_D:    Plant Production on demand ratio 
%           production at previous cycle Q(i -1) or seed Q*aQo / demand at cycle i
%   I:   i          : the cycle the computation applies to
%   I:   b2         : probability of the organ occurrence
%   I:   Axdc(i,s)  : the  axis of development
%   I:   tfo        : organ functioning duration time
%   I:   nmo        : remobilisation "intensity"
%   I:   co         : remobilisation coefficient (= 0: no remobilization)
%   I:   no(i,s)    : organ cohort occurences 
%   I:   nf(i,s)    : fruit cohort occurrences (make cause a feed back on sink multiplying it by kpo) 
%   I:   po         : sink function ratio (relative to leaf one)
%   I:   kpo        : sink ratio fruit feedback (if kpo > 0)
%   I:   Bo(j,Period): Sink variation BetaLaw 
%   I:   dim        : Max ctcle number (qo dimension)
%   I:   offs       : ofset due to s (s-1)*dim
%   I:   offset     : qo table offset (due to s value)
%   I&O: qo(i,j,s)  : organ production at cycle i when born at cycle j ( j <=i)
%   I&O: Qmob_is:   : Pool for remobilization at cycle i
%   I&O: TQo_is:    : Total organ biomass at cycle i
%
%
    if po > 0
        sdim = (s-1)*dim;
        for j = 1: i
            ij = (j-1)*dim + i;
            js = sdim + j;
            ijs = sdim*dim + ij;
            dto = i - j + 1;
            %% organ expansion
            if  dto-Dlo > 0 && no(js) > 0
                if (Axdc(js) > 0)
                    dqi = po * Q_D * Bo(j,dto-Dlo);
                    if nf(js) > 0 && kpo > 0
                        dqi = kpo * dqi;
                    end
                 else
                    dqi = 0;
                end
                if i == 1
                    qo(ijs) = dqi ;%  volume premier cycle
                else
                    qo(ijs) = qo(ijs-1) + dqi ;
                end
                % Test MJ181016 mxqo(i,j,s) = qo(i,j,s);
            end
%                 %% organ remobilisation
%             if i > 1 && dto > tfo  && co > 0
%                 % Test MJ181016 qo(i,j,s) = mxqo(i,j,s) * (1-mno*(1-(1-co)^(dto-tfo)));
%                 qo(i,j,s) = qo(i,j,s) * (1-mno*(1-(1-co)^(dto-tfo)));
%                 Qmob_is = Qmob_is + qo(i-1,j,s) - qo(i,j,s);
%             end
            %so(i,j,s)=qo(i,j,s)/e;
            %CCC qomc(i,j) = qomc(i,j) + qo(i,j,s);
            %mxqomc(i,j) = mxqomc(i,j) + mxqo(i,j,s);
            if qo(ijs) > 0
                 %% organ remobilisation
                if co > 0 && dto > tfo  && i > 1
                    % Test MJ181016 qo(i,j,s) = mxqo(i,j,s) * (1-mno*(1-(1-co)^(dto-tfo)));
                    qo(ijs) = qo(ijs) * (1-mno*(1-(1-co)^(dto-tfo)));
                    Qmob_is = Qmob_is + qo(ijs-1) - qo(ijs);
                end
                qomc(ij) = qomc(ij) + qo(ijs);
                nqomc(ij) = nqomc(ij) + 1;
                TQo_is  = TQo_is  + no(js) * qo(ijs);
            else
                qo(ijs) = 0.0000001; % organ always exists
            end

            %CCC  TQo_is  = TQo_is  + no(j,s) * qo(i,j,s);% local compartment for s for all j
            %nTQo_is = nTQo_is + no(j,s) * sign(qo(i,j,s));

        %     TQo(i,1)  = TQo(i,1)  + no(j,s) * qo(i,j,s);% global compartment
        %     nTQo(i,1) = nTQo(i,1) + no(j,s) * sign(qo(i,j,s));
            %CCC if qo(i,j,s) == 0
            %CCC    qo(i,j,s) = 0.000001;% always organ exist
            %CCC end
        end
    end
    
end
