%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% StemGL_Fit Single stem Greenlab Fitting tool and
% StemGL_Sim Single stem GreenLab Simulation tool
%
%   MatLab_Octave code. 
%
% This code is part of GREENLAB project StemGL implementation
%
% Main Author: Philippe de Reffye CIRAD-AMAP
% Secondary author: Marc JAEGER CIRAD-AMAP
%
% Created: 2018
% Version 18_10_05
%
% Copyright (C) 2018 CIRAD-AMAP 
%
% This program is free software: you can redistribute it and/or modify it
% under the terms of the Create Commons Licence  type 5, BY-NC-SA
% BY (Attribution): Licensees may copy, distribute, display and perform the work and make derivative
% works and remixes based on it only if they give the author or licensor the credits (attribution)
% in the manner specified by these.
% SA (Share-alike): Licensees may distribute derivative works only under a license identical
% ("not more restrictive") to the license that governs the original work.
% NC (Non-commercial): 	Licensees may copy, distribute, display, and perform the work and
% make derivative works and remixes based on it only for non-commercial purposes.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Dt,Qt,TQt,TQAt,TQPt,TQICt,TQFt,TQMt,TQRt,TQTt,Ba,Bp,Bi,Bc,Bf,Bm,Bt,...
    qat,qpt,qict,qft,qmt,qdict,qlit,qdat,qlat,qdft,qlft,qdmt,qlmt,X0,Y0,XX,YY,ZZ,...
    Qo,Sp,r,pp,pe,pc,pf,pm,pt,kpc,kpa,kpe,ca,cp,ci,...
    Ba1,Bp1,Bi1,Bf1,Bm1,Bt1,Ba2,Bp2,Bi2,Bf2,Bm2,Bt2]=...
    fit_GL(modH,Lsqr,N_iter,chpm,comp,T,Tm,mxTob,Tob,...
    tfa,tfp,tfi,tff,tfm,tft,txa,txp,txi,txc,txf,txm,txt,...
    na,np,ni,nf,nm,nt,AxdPot,PBN,MiPBN,MxPBN,e,b1,a1,f1,...
    Ba1,Ba2,Bp1,Bp2,Bi1,Bi2,Bc1,Bc2,Bf1,Bf2,Bm1,Bm2,Bt1,Bt2,Dla,Dlp,Dli,Dlc,Dlf,Dlm,Dlt,...
    E,bf,Qo,aQo,aQr,Sp,kc,r,pa,pp,pe,pc,pf,pm,pq,pt,kpc,kpa,kpe,...
    mna,ca,mnp,cp,mni,ci,c1,c2,Hmx,Hmn,H1,psi,DH,...
    TQAob,TQPob,TQICob,TQFob,TQMob,TQTob,qaob,qpob,qicob,qfob,qmob)

global USE_CPP;
USE_CPP_OFF = 0;

[x,y]=size(chpm); 
DMS=0;WM=0;WPD=0;WDAT=0;WDD=0;WPAR=0;WDPAR=0;WEPAR=0;EQUI=0;
    WDEVPAR=0;ERR=0;XPAR=0;NPAR=0;
    % MJ 18/10/19 Axdc = round (AxdPot + 0.499999);
    
if Lsqr==1
    NVAR=x; 
    [WM,WPD,WO,DMS] =fit_targetQ(comp,T,mxTob,Tob,TQAob,TQPob,TQICob,TQFob,TQMob,TQTob,...
        qaob,qpob,qicob,qfob,qmob,pa,pp,pe,pf,pm,pt);
    %%%%%%%%%% Array for GLSM
    WDAT=zeros(DMS,1);WDD=zeros(NVAR,NVAR);
    WPAR=zeros(NVAR, DMS);WDPAR=zeros(NVAR,1); WEPAR=zeros(NVAR,1);
    EQUI=zeros(NVAR,1);WDEVPAR=zeros(NVAR,1);
    XPAR=zeros(NVAR, 3);XDEVPAR=zeros(NVAR,1); XEPAR=zeros(NVAR,1);
     SPAR=['xQo___';'xaQo__';'xr____';'xSp___';'xpp___';'xpe___';'xpc___';...
        'xpf___';'xpm___';'xpt___';'xkpc__';'xkpa__';'xkpe__';...
        'ca____';'cp____';'ci____';'c1____';'c2____';'x19___';...
        'x20___';'x21___';'x22___';'x23___';'x24___';...
        'xBa1__';'xBp1__';'xBi1__';'xBf1__';'xBm1__';'xBt1__';...
        'xBa2__';'xBp2__';'xBi2__';'xBf2__';'xBm2__';'xBt2__';];
    ERR=0;
    % Variable transfert%
    A=zeros(NVAR,1);x_A=zeros(NVAR,1);
    pa=1;% fixed
    A(1)=Qo;   A(2)=aQo;  A(3)=r;    A(4)=Sp;   A(5)=pp;   A(6)=pe; A(7)=pc;
    A(8)=pf;   A(9)=pm;   A(10)=pt;  A(11)=kpc; A(12)=kpa; A(13)=kpe;
    A(14)=ca;  A(15)=cp;  A(16)=ci;  A(17)=c1;  A(18)=c2;
    A(19)=0;   A(20)=0;   A(21)=0;   A(22)=0;   A(23)=0;   A(24)=0;
    A(25)=Ba1; A(26)=Bp1; A(27)=Bi1; A(28)=Bf1; A(29)=Bm1; A(30)=Bt1;
    A(31)=Ba2; A(32)=Bp2; A(33)=Bi2; A(34)=Bf2; A(35)=Bm2; A(36)=Bt2;
    % choix param
    XPAR(1:NVAR,1)=chpm(1:NVAR,1);
    % storing param, initializing solution, dx for numerical differentiation
    XPAR(:,2) = A(:,1);
    XDEVPAR(:,1) = A(:,1)/10000;
    XEPAR(:,1) = 0.001*A(:,1); % to adjust dx to x
    for i=1:NVAR 
        XDEVPAR(i) = (-1)^i*XDEVPAR(i); 
    end ;%to help start
    NPAR=1;
    % Check function for parameters selection
    [WPAR,WDEVPAR,WEPAR,EQUI,NPAR,DSPAR1,DSPAR2] =...
        fit_lsqr_par(NVAR,XPAR,XDEVPAR,XEPAR,WPAR,WDEVPAR,WEPAR,EQUI,NPAR,SPAR);
    if NPAR == 0 
        N_iter=1; 
    end  
    % TRANSFER TO WORKING VARIABLES
    XPAR(:,3) = XPAR(:,2);
end
% when bstd==true, pso will call this function to compute variance
% *************************
% *LOOP for iterations
%%%%%%%%%%%%%%%%%%%%%%%%%%%
for iter = 1 : N_iter% Loop for accuracy on the fitted parameters,iter-----grad
    deriv = 1;
    if iter > 1
        deriv = NPAR+1;
    end
    if iter > 1
        %fprintf(1,' iter = %g ',iter);
        for i = 1:NPAR
            fprintf(1,' %6.3f ',WPAR(i,iter-1));
        end
        fprintf(1,' \n');
        fprintf(1,' iter = %g ',iter); fprintf(1,' error = %g ',ERR);
        fprintf(1,' \n');
    end
    % *************************
    % LOOP for derivatives
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if iter == N_iter
        deriv =1;
    end
    for pass = 1 : deriv % Loop for the derivative of least square method,pass-----pass
        if Lsqr == 1
            if  iter > 1
                %gives the new values of XPAR(:,3) toward the solution
                [XPAR,WPAR] = fit_lsqr_dx(NVAR,XPAR,WDPAR,WPAR,WDEVPAR,WEPAR,EQUI,NPAR,pass,iter);
            end
            % Update the hidden parameters
            x_A(:,1)=XPAR(:,3); %
            % affectation
            Qo=x_A(1);   aQo=x_A(2);  r=x_A(3);    Sp=x_A(4);   pp=x_A(5);   pe=x_A(6);
            pc=x_A(7);   pf=x_A(8);   pm=x_A(9);   pt=x_A(10);  kpc=x_A(11); kpa=x_A(12);
            kpe=x_A(13); ca=x_A(14);  cp=x_A(15);  ci=x_A(16);  c1=x_A(17);  c2=x_A(18); x19=x_A(19);
            x20=x_A(20); x21=x_A(21); x22=x_A(22); x23=x_A(20); x24=x_A(24); Ba1=x_A(25);
            Bp1=x_A(26); Bi1=x_A(27); Bf1=x_A(28); Bm1=x_A(29); Bt1=x_A(30); Ba2=x_A(31);
            Bp2=x_A(32); Bi2=x_A(33); Bf2=x_A(34); Bm2=x_A(35); Bt2=x_A(36);
        end
        
        
        %sink variation function
        if USE_CPP
            [Ba] = CPPGrowth_Beta2(T,txa,Ba1,Ba2); % Beta law for blade
            [Bp] = CPPGrowth_Beta2(T,txp,Bp1,Bp2); % Beta law for petiol
            [Bi] = CPPGrowth_Beta2(T,txi,Bi1,Bi2); % Beta law for internode
            [Bc] = CPPGrowth_Beta2(T,txc,Bc1,Bc2); % Beta law for ring
            [Bf] = CPPGrowth_Beta2(T,txf,Bf1,Bf2); % Beta law for female fruit
            [Bm] = CPPGrowth_Beta2(T,txm,Bm1,Bm2); % Beta law for male fruit
            [Bt] = CPPGrowth_Beta2(T,txt,Bt1,Bt2); % Beta law for tape root
        else
            [Ba] = Growth_Beta(T,txa,Ba1,Ba2); % Beta law for blade
            [Bp] = Growth_Beta(T,txp,Bp1,Bp2); % Beta law for petiol
            [Bi] = Growth_Beta(T,txi,Bi1,Bi2); % Beta law for internode
            [Bc] = Growth_Beta(T,txc,Bc1,Bc2); % Beta law for ring
            [Bf] = Growth_Beta(T,txf,Bf1,Bf2); % Beta law for female fruit
            [Bm] = Growth_Beta(T,txm,Bm1,Bm2); % Beta law for male fruit
            [Bt] = Growth_Beta(T,txt,Bt1,Bt2); % Beta law for tape root
        end
     
        % Compute Demand
        %
        Dt=zeros(T,1);
        Slat=zeros(T,T);       
        D_rings = zeros(T,1);
        
        %fprintf (1,'CG  Total  Leaf   Petiol   Internode   FruitF   FruitM   Rings   TapeRoot   pq\n');
        
        for i =1:T
            if USE_CPP 
                % leaf demand
                D_blade = CPPOrgan_DemandFit(i,na,nf,1,pa,kpa,Ba,Dla,AxdPot,T);
                % petiol demand
                D_petiol = CPPOrgan_DemandFit(i,np,nf,1,pp,kpa,Bp,Dlp,AxdPot,T);
                %internode demand
                D_internode = CPPOrgan_DemandFit(i,ni,nf,1,pe,kpe,Bi,Dli,AxdPot,T);
                % female fruit demand
                D_ffruit = CPPOrgan_DemandFit(i,nf,nf,bf,pf,1,Bf,Dlf,AxdPot,T);
                % male fruit demand
                D_mfruit = CPPOrgan_DemandFit(i,nm,nf,1,pm,1,Bm,Dlm,AxdPot,T);          
                %ring demand && leaf seen
            else
                % leaf demand
                D_blade = Organ_DemandFit(i,na,nf,1,pa,kpa,Ba,Dla,AxdPot);
                % petiol demand
                D_petiol = Organ_DemandFit(i,np,nf,1,pp,kpa,Bp,Dlp,AxdPot);
                %internode demand
                D_internode = Organ_DemandFit(i,ni,nf,1,pe,kpe,Bi,Dli,AxdPot);
                % female fruit demand
                D_ffruit = Organ_DemandFit(i,nf,nf,bf,pf,1,Bf,Dlf,AxdPot);
                % male fruit demand
                D_mfruit = Organ_DemandFit(i,nm,nf,1,pm,1,Bm,Dlm,AxdPot);          
                %ring demand && leaf seen
            end
            if pc >0
                Lat = zeros(T,1);
                if (i > tfa)
                    i0 = i-tfa+1;
                else
                    i0 = 1;
                end
                for j =i0:i
                    Lat(j) = na(i)*AxdPot(j);
                    D_rings(i) = D_rings(i) + pc*Lat(j);
                end
                if i < Dlc
                   D_rings(i)=0;
                end
                for j =1:i
                    Slat(i,j) = sum(Lat(j:i));% sum of leaf seen from rank of phytomer
                end
            end
            % tape root demand
            D_root = 0;
            if i > Dlt
                D_root = pt*Bt(1,i-Dlt);
            end
            % total demand (+tape_root + pool)
            Dt(i) = D_blade + D_petiol +D_internode + D_ffruit + D_mfruit +D_rings(i)+ D_root + pq;%

        end
        i=T;
        %fprintf (1,'%d) %g   %g   %g   %g   %g   %g   %g   %g   %g\n', i, Dt(i),D_blade,D_petiol,D_internode,D_ffruit,D_mfruit,D_rings(i),D_root,pq);

                   
        
        %%%%%%%%%%%%%%%%%%%%%%%%%
        % GROWTH computation and data results storages Size of organs
        %%%%%%%%%%%%%%%%%%%%%%%
        if USE_CPP
            [Qt,TQt,TQAt,TQPt,TQICt,TQFt,TQMt,TQRt,TQTt,...
                qat,qpt,qict,qft,qmt,qlit,qdict,qdat,qlat,qdft,qlft,qdmt,qlmt] = CPPGrowth_Fit(modH,T,Tm,Dt,D_rings,Slat,...
                tfa,tfp,tfi,tff,tfm,tft,na,np,ni,nf,nm,nt,Ba,Bp,Bi,Bc,Bf,Bm,Bt,Dla,Dlp,Dli,Dlc,Dlf,Dlm,Dlt,......
                AxdPot,b1,a1,f1,E,bf,Qo,aQo,aQr,e,Sp,kc,r,...
                pa,pp,pe,pc,pf,pm,pq,pt,kpc,kpa,kpe,mna,ca,mnp,cp,mni,ci,c1,c2,Hmx,Hmn,H1,psi,DH);
        else
            [Qt,TQt,TQAt,TQPt,TQICt,TQFt,TQMt,TQRt,TQTt,...
                qat,qpt,qict,qft,qmt,qlit,qdict,qdat,qlat,qdft,qlft,qdmt,qlmt] = Growth_Fit(modH,T,Tm,Dt,D_rings,Slat,...
                tfa,tfp,tfi,tff,tfm,tft,na,np,ni,nf,nm,nt,Ba,Bp,Bi,Bc,Bf,Bm,Bt,Dla,Dlp,Dli,Dlc,Dlf,Dlm,Dlt,......
                AxdPot,b1,a1,f1,E,bf,Qo,aQo,aQr,e,Sp,kc,r,...
                pa,pp,pe,pc,pf,pm,pq,pt,kpc,kpa,kpe,mna,ca,mnp,cp,mni,ci,c1,c2,Hmx,Hmn,H1,psi,DH);
        end
        
        % MJ 18/10/19
        Axdc = round (AxdPot + 0.499999);
        [qat,qpt,qict,qft,qmt]=...
            Growth_Ax_Sorta (T,Axdc,PBN,MiPBN,MxPBN,nf,nm,pa,pp,pe,pc,pf,pm,pt,qat,qpt,qict,qft,qmt);
        %
        [moTQAt,moTQPt,moTQICt,moTQFt,moTQMt,moTQTt,moqat,moqpt,moqict,moqft,moqmt]=...
            Growth_Obs( Lsqr,comp,T,mxTob,Tob,TQAt,TQPt,TQICt,TQFt,TQMt,TQTt,...
            qat,qpt,qict,qft,qmt,TQAob,TQPob,TQICob,TQFob,TQMob,TQTob,...
            qaob,qpob,qicob,qfob,qmob,pa,pp,pe,pc,pf,pm,pt);
        % store the computed data for glsqr
        if Lsqr ==1
            [WM,WPD,x]=fit_targetQ_update(pass,comp,T,mxTob,Tob,...
                moTQAt,moTQPt,moTQICt,moTQFt,moTQMt,moTQTt,...
                moqat,moqpt,moqict,moqft,moqmt,...
                TQAob,TQPob,TQICob,TQFob,TQMob,TQTob,...
                qaob,qpob,qicob,qfob,qmob,...
                pa,pp,pe,pc,pf,pm,pt,WDAT,WM,WPD);
        end
    end % for pass = 1:NPAR+1. All the derivatives are done
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if  pass >1 && Lsqr ==1;
        [WDPAR,WDD,ERR] = fit_lsqr_main(x,NPAR,iter,WM,WEPAR,WPD,WDD,WPAR,WDPAR);
    end
end % for iter =1 :N_iter
if Lsqr ==0
    X0=0;Y0=0;XX=0;YY=0;maxXY=0;ZZ=0;
end
if Lsqr ==1 && iter >0
    % to test fitting conputed data versus observed data
    XX(:,1)=WM(:,1).*WPD(:,1); YY(:,1)=WM(:,2).*WPD(:,1);ZZ(:,1)=WO(:,1);
    maxXY=max(XX);
    X0=[0,maxXY];Y0=[0,maxXY];
    fprintf(1,' \n');
    %********************************************
    % estimation of the variances for parameters
    %*********************************************
    % computing total variation (Y'.W.Y)
    fprintf(1,' ERROR %g',ERR);
    fprintf(1,' \n');
    S2M = 0;
    for i = 1 :DMS
        S2M = S2M + (WM(i, 1+0) - WM(i, 1+1))*WPD(i,1) * (WM(i, 1+0) - WM(i, 1+1));
    end
    S2M = S2M / (DMS - NPAR);
    % computing standard deviation of parameters = sqr(S2M).vii
    %(vii = diagonal item from XWX^-1)
    for i = 1 :NPAR
        WDPAR(i,1) = sqrt(S2M * WDD(i, i));
    end
    %%% display selected fitting parameter
        disp(DSPAR1);disp(DSPAR2);
    fprintf(1,' \n');
    for i = 1:NPAR
        fprintf(1,'  A %g',i);fprintf(1,'=%g',WPAR(i,N_iter));
    end
    fprintf(1,' \n');
    % standard deviation for hidden parameters
    for i = 1:NPAR
        fprintf(1,' sA %g',i);fprintf(1,'=%g', WDPAR(i,1));
    end
    fprintf(1,' \n');
end
