%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% StemGL_Fit Single stem Greenlab Fitting tool and
% StemGL_Sim Single stem GreenLab Simulation tool
%
%   MatLab_Octave code. 
%
% This code is part of GREENLAB project StemGL implementation
%
% Main Author: Philippe de Reffye CIRAD-AMAP
% Secondary author: Marc JAEGER CIRAD-AMAP
%
% Created: 2018
% Version 18_10_05
%
% Copyright (C) 2018 CIRAD-AMAP 
%
% This program is free software: you can redistribute it and/or modify it
% under the terms of the Create Commons Licence  type 5, BY-NC-SA
% BY (Attribution): Licensees may copy, distribute, display and perform the work and make derivative
% works and remixes based on it only if they give the author or licensor the credits (attribution)
% in the manner specified by these.
% SA (Share-alike): Licensees may distribute derivative works only under a license identical
% ("not more restrictive") to the license that governs the original work.
% NC (Non-commercial): 	Licensees may copy, distribute, display, and perform the work and
% make derivative works and remixes based on it only for non-commercial purposes.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function plot_HistoA(Lsqr,comp,E,T,Tm,Tob,mxTob,pa,pp,pe,pc,pf,pm,pq,pt,Dt,Qt,TQt,X0,Y0,XX,YY,ZZ,...
    TQAT,TQAob,TQPT,TQPob,TQICT,TQICob,TQFT,TQFob,TQMT,TQMob,TQTT,TQTob,...
    qat,qaob,qpt,qpob,qict,qicob,qft,qfob,qmt,qmob,...
    txa,txp,txi,txc,txf,txm,txt,Ba,Bp,Bi,Bc,Bf,Bm,Bt,Dla,Dlp,Dli,Dlc,Dlf,Dlm,Dlt)
fg=2;SinkOrg=zeros(1,2*T);Borg=zeros(1,2*T);
figure (fg)
set (figure (fg), 'Name', 'Demand & Biomass');
maxDt=max(Dt);maxDt=maxDt+maxDt/4;
XDt=[0,T];
YDt=[maxDt,maxDt];
if Lsqr>0
    subplot(2,2,1)
    plot(X0,Y0,'- k');
    hold on
    [WX,WY]=size(XX);
    for i=1:WX
        if ZZ(i,1) <10
            plot(XX(i,1),YY(i,1),'o k','MarkerSize',5);
        else
            plot(XX(i,1),YY(i,1),'* k','MarkerSize',5);
        end
    end
    title ('fitting overview')
    hold on
end
subplot(2,2,2)
plot(E,'k');
title('climate data')
hold on
subplot(2,2,3)
plot(0,max(YDt)*1.1)
hold on
plot(XDt,YDt,'- w');
title('Demand/Cycle')
hold on
plot(Dt,'- k','LineWidth',2)
hold off
subplot(2,2,4)
plot(0,max(Qt)*1.1)
hold on
plot(Qt,'- k','LineWidth',2);title('Biomass/Cycle')
fg=fg+1;
hold off
%%%%%%%%%%%% organ expansion time
figure (fg)
set (figure (fg), 'Name', 'organ expansion time/rank');
TT=zeros(T,1);
TX=zeros(T,1);
for t =1:T
    TT(t,1)=t;
    TX(t,1)=max(txa(t,:));
end
subplot(2,3,1)
plot(0,0)
hold on
plot(1,max(txa(T,:))+5)
hold on
plot(TT(:,1),TX(:,1),'- g','LineWidth',2);
title ('leaf expansion time')
hold on
if pp >0
    for t =1:T
        TT(t,1)=t;TX(t,1)=max(txp(t,:));
    end
    subplot(2,3,2)
    plot(0,0)
    hold on
    plot(1,max(txp(T,:))+5)
    hold on
    plot(TT(:,1),TX(:,1),'- b','LineWidth',2);
    title ('petiol sheath expansion time')
    hold on
end
if pe >0
    for t =1:T
        TT(t,1)=t;TX(t,1)=max(txi(t,:));
    end
    subplot(2,3,3)
    plot(0,0)
    hold on
    plot(1,max(txi(T,:))+5)
    hold on
    plot(TT(:,1),TX(:,1),'- b','LineWidth',2);
    title ('internode expansion time')
    hold on
end
if pf >0
    for t =1:T
        TT(t,1)=t;TX(t,1)=max(txf(t,:));
    end
    subplot(2,3,4)
    plot(0,0)
    hold on
    plot(1,max(txf(T,:))+5)
    hold on
    plot(TT(:,1),TX(:,1),'- r','LineWidth',2);
    title ('fruit fem. expansion time')
    hold on
end
if pm >0
    for t =1:T
        TT(t,1)=t;TX(t,1)=max(txm(t,:));
    end
    subplot(2,3,5)
    plot(0,0)
    hold on
    plot(1,max(txm(T,:))+5)
    hold on
    plot(TT(:,1),TX(:,1),'- c','LineWidth',2);
    title ('fruit mal. expansion time')
    hold on
end
if pt >0
    for t =1:T
        TT(t,1)=t;TX(t,1)=max(txt(t,:));
    end
    subplot(2,3,6)
    plot(0,0)
    hold on
    plot(1,max(txt(T,:))+5)
    hold on
    plot(TT(:,1),TX(:,1),'- m','LineWidth',2);
    title ('root expansion time')
end
hold off
fg=fg+1;
%%%%%%%%%% sink variation law of organ
set(figure (fg), 'Name', 'Sink variation law');
if max(txa) >T
    St=T;
else
    St=max(txa);
end
SinkOrg=zeros(1,Dla+St);Borga=zeros(1,St);
for s =1:St+Dla
    Borga(1,s)=Ba(T,s)*pa;
    SinkOrg(1,s+Dlp)=Borga(1,s);
end
subplot(2,3,1)
plot(0,0)
hold on
plot(0,max(SinkOrg)+0.2)
hold on
plot(SinkOrg,'- g','LineWidth',2);
title('leaf sink variation')
hold on
if max(txp) >T
    St=T;
else
    St=max(txp);
end
if pp >0
    SinkOrg=zeros(1,Dlp+St);Borgp=zeros(1,St);
    for s =1:St+Dlp
        Borgp(1,s)=Bp(T,s)*pp;
        SinkOrg(1,s+Dlp)=Borgp(1,s);
    end
    subplot(2,3,2)
    plot(0,0)
    hold on
    plot(0,max(SinkOrg)+0.5)
    hold on
    plot(SinkOrg,'-- g','LineWidth',2);
    title('petiol-sheath sink variation')
    hold on
end
if pe >0 && max(txi)>0 
    if max(txi) >T
        St=T;
    else
        St=max(txi);
    end
    SinkOrg=zeros(1,Dli+St);Borgi=zeros(1,St);
    for s =1:St+Dli
        Borgi(1,s)=Bi(T,s)*pe;
        SinkOrg(1,s+Dli)=Borgi(1,s);
    end
    subplot(2,3,3)
    plot(0,0)
    hold on
    plot(0,max(SinkOrg)+0.2)
    hold on
    plot(SinkOrg,'- b','LineWidth',2);
    title('internode sink variation')
    hold on
end
if pf >0
    if max(txf) >T
        St=T;
    else
        St=max(txf);
    end
    SinkOrg=zeros(1,Dlf+St);Borgf=zeros(1,St);
    for s =1:St%
        Borgf(1,s)=Bf(T,s)*pf;
        SinkOrg(1,s+Dlf)=Borgf(1,s);
    end
    subplot(2,3,4)
    plot(0,0)
    hold on
    plot(0,max(SinkOrg)+0.2)
    hold on
    plot(SinkOrg,'- r','LineWidth',2);
    title('fruit fem. sink variation')
    hold on
end
if pm >0
    if max(txm) >T
        St=T;
    else
        St=max(txm);
    end
    SinkOrg=zeros(1,Dlm+St);Borgm=zeros(1,St);
    for s =1:St+Dlm
        Borgm(1,s)=Bm(T,s)*pm;
        SinkOrg(1,s+Dlm)=Borgm(1,s);
    end
    subplot(2,3,5)
    plot(0,0)
    hold on
    plot(0,max(SinkOrg)+0.2)
    hold on
    plot(SinkOrg,'- c','LineWidth',2);
    title('fruit mal. sink variation')
    hold on
end
if pt >0
    if max(txt) >T
        St=T;
    else
        St=max(txt);
    end
    SinkOrg=zeros(1,Dlt+St);Borgt=zeros(1,St);
    for s =1:St
        Borgt(1,s)=Bt(T,s)*pt;
        SinkOrg(1,s+Dlt)=Borgt(1,s);
    end
    subplot(2,3,6)
    plot(0,0)
    hold on
     plot(0,max(SinkOrg)+0.2)
     hold on
    plot(SinkOrg,'- m','LineWidth',2);
    title('root sink variation')
end
hold off
fg=fg+1;
if comp(1,1) >0
    %%%%%%%%% biomass/ compartment of organs
    figure (fg)
    set (figure (fg), 'Name', 'Biomass/Compartment');
    %%%% leaf
    subplot(2,3,1)
    plot(TQAT,'- g','LineWidth',2)
    hold on
    plot(TQAob,'o g','markersize',6);
    title('biomass leaves')
    hold on,
    if pp >0
        % petiol-sheath
        plot(TQPT,'-- g','LineWidth',2)
        hold on
        plot(TQPob,'* g');
        title('biomass petiols-sheaths')
        hold on
    end
    if pe>0
        %%%% internode pith+rings
        subplot(2,3,2)
        plot(TQICT,'- b','LineWidth',2)
        hold on
        plot(TQICob,'o b','markersize',6);
        title('biomass internodes')
        hold on
    end
    if pf >0
        %%%% female fruits
        subplot(2,3,3)
        plot(TQFT,'- r','LineWidth',2)% fem
        hold on
        plot(TQFob,'o r','markersize',6);
        title('biomass fruits fem')
        hold on;
    end
    if pm >0
        %%%% male fruits
        plot(TQMT,'- c','LineWidth',2)% mal
        hold on
        plot(TQMob,'o c','markersize',6);
        title('biomass fruits mal')
        hold on;
    end
    if pt >0
        %%%% Tape root
        subplot(2,3,4)
        plot(TQTT,'- m','LineWidth',2)
        hold on
        plot(TQTob,'o m','markersize',6);
        title('biomass roots')
    end
    %total biomass
    subplot(2,3,5)
     plot(TQAT,'- g','LineWidth',2)
     hold on
     plot(TQPT,'-- g','LineWidth',2)
     hold on
     plot(TQICT,'- b','LineWidth',2)
     hold on
     plot(TQFT,'- r','LineWidth',2)% fem
     hold on
     plot(TQMT,'- c','LineWidth',2)% mal
     hold on
     plot(TQTT,'- m','LineWidth',2)
     hold on
     plot(TQt,'- k','LineWidth',2)
     title('All biomass')
    hold off
end
if comp(1,2) >0
    % series organic computed topological
    %%%%%%%%%%%%%%%%%%%%
    %% conditioning fruit organic series
    %% fruit biomass must exist event very small
    for i=1:mxTob
        for j =1:max(Tob)
            if pf >0 && qfob(j,i)== -0.0001 && qicob(j,i) >0
                if j <= Tm
                    qfob(j,i)=0.0001;qft(j,Tob(i))=0.0001;
                end
            end
        end
    end
    %% supress non data =999
    for i=1:mxTob
        for j =1:max(Tob)
            if pa >0
                if qaob(j,i)==999
                    qaob(j,i)=0.0001;
                end
            end
            if pp >0
                if qpob(j,i)==999
                    qpob(j,i)=0.0001;
                end
            end
            if pe >0
                if qicob(j,i)==999
                    qicob(j,i)=0.0001;
                end
            end
            if pf >0
                if qfob(j,i)==999
                    qfob(j,i)=0.0001;
                end
            end
        end
    end
    fg=fg+1;
    figure (fg)
    set (figure (fg), 'Name', 'Phytomer biomass/organic series');
    Tplot=T;
    %%leaves
    subplot(2,3,1)
    [qaob]=crunchq_upqo(qaob,T);
    for k=1:mxTob
        Ti=Tob(1,k);
        if Ti >0
            Tplot=Ti;
            if Ti>Tm
                Tplot=Tm+1;
            end
            [qatw] =selectA(T,Ti,qat);
            [qatw]=crunchq_upqos(qatw,Ti);
            plot (qatw(1:Tplot,1),'- g','LineWidth',2)
            hold on
            qo(:,1)=qaob(:,k);
           [qo]=crunchq_upqos(qo,Ti);
            plot(qo(1:Tplot,1),'o g','markersize',5)
        end
        hold on
    end
    title('leaves organic series')
    hold on
    if pp >0
        %petiol sheath
        subplot(2,3,2)
        [qpob]=crunchq_upqo(qpob,T);
        for k=1:mxTob
            Ti=Tob(1,k);
            if Ti >0
                Tplot=Ti;
                if Ti>Tm
                    Tplot=Tm+1;
                end
                [qptw] =selectA(T,Ti,qpt);
                [qptw]=crunchq_upqos(qptw,Ti);
                plot (qptw(1:Tplot,1),'-- g','LineWidth',2)
                hold on
                qo(:,1)=qpob(:,k);
                [qo]=crunchq_upqos(qo,Ti);
                plot(qo(1:Tplot,1),'* g','markersize',5)
            end
            hold on
        end
        title('petiols-sheats organic series')
    end
    %% internodes
    if pe >0
        subplot(2,3,3)
        [qicob]=crunchq_upqo(qicob,T);
        for k=1:mxTob
            Ti=Tob(1,k);
            if Ti >0
                Tplot=Ti;
                if Ti>Tm
                    Tplot=Tm+1;
                end
                [qictw] =selectA(T,Ti,qict);
                [qictw]=crunchq_upqos(qictw,Ti);
                plot (qictw(1:Tplot,1),'- b','LineWidth',2)
                hold on
                qo(:,1)=qicob(:,k);
                [qo]=crunchq_upqos(qo,Ti);
                plot(qo(1:Tplot,1),'o b','markersize',5)
            end
            hold on
        end
        title('internodes organic series')
    end
    hold on
    if pf >0
        subplot(2,3,4)
        [qfob]=crunchq_upqo(qfob,T);
        for k=1:mxTob
            Ti=Tob(1,k);
            if Ti >0
                Tplot=Ti;
                if Ti>Tm
                    Tplot=Tm+1;
                end
                [qftw] =selectA(T,Ti,qft);
                [qftw]=crunchq_upqos(qftw,Ti);
                plot (qftw(1:Tplot,1),'- r','LineWidth',2)
                hold on
                qo(:,1)=qfob(:,k);
                [qo]=crunchq_upqos(qo,Ti);
                plot(qo(1:Tplot,1),'o r','markersize',5)
            end
            hold on
        end
        title('fruit fem.organic series')
        hold on
    end
    if pm >0
        subplot(2,3,5)
        [qmob]=crunchq_upqo(qmob,T);
        for k=1:mxTob
            Ti=Tob(1,k);
            if Ti >0
                Tplot=Ti;
                if Ti>Tm
                    Tplot=Tm+1;
                end
                [qmtw] =selectA(T,Ti,qmt);
                [qmtw]=crunchq_upqos(qmtw,Ti);
                plot (qmtw(1:Tplot,1),'- c','LineWidth',2)
                hold on
                qo(:,1)=qmob(:,k);
                [qo]=crunchq_upqos(qo,Ti);
                plot(qo(1:Tplot,1),'* c','markersize',5)
            end
            hold on
        end
        hold off
    end
end